Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/pages.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/pages.py	(revision 8366)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/pages.py	(revision 8367)
@@ -311,5 +311,5 @@
     grok.name('administration')
     grok.context(IUniversity)
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.managePortal')
     label = _(u'Administration')
     pnav = 0
@@ -356,5 +356,5 @@
     grok.context(IUniversity)
     grok.name('reindex')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.managePortal')
 
     def update(self,ctlg=None):
@@ -594,5 +594,5 @@
     grok.name('search')
     grok.template('searchpage')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.viewAcademics')
     label = _(u"Search Academic Section")
     pnav = 1
@@ -863,5 +863,5 @@
     grok.name('import1')
     grok.template('datacenterimport1page')
-    grok.require('waeup.manageDataCenter')
+    grok.require('waeup.importData')
     label = _(u'Process CSV file')
     pnav = 0
@@ -893,5 +893,5 @@
     grok.name('import2')
     grok.template('datacenterimport2page')
-    grok.require('waeup.manageDataCenter')
+    grok.require('waeup.importData')
     label = _(u'Process CSV file')
     pnav = 0
@@ -1013,5 +1013,5 @@
     grok.name('import3')
     grok.template('datacenterimport3page')
-    grok.require('waeup.manageDataCenter')
+    grok.require('waeup.importData')
     label = _(u'Process CSV file')
     pnav = 0
@@ -1121,5 +1121,5 @@
     grok.name('import4')
     grok.template('datacenterimport4page')
-    grok.require('waeup.manageDataCenter')
+    grok.require('waeup.importData')
     label = _(u'Process CSV file')
     pnav = 0
@@ -1178,5 +1178,5 @@
     grok.name('logs')
     grok.template('datacenterlogspage')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageDataCenter')
     label = _(u'Show logfiles')
     pnav = 0
@@ -1200,5 +1200,5 @@
     grok.name('show')
     grok.template('datacenterlogsshowfilepage')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageDataCenter')
     title = _(u'Data Center')
     pnav = 0
@@ -1275,5 +1275,5 @@
     grok.name('export')
     grok.template('datacenterexportpage')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageDataCenter')
     label = _('Download portal data as CSV file')
     pnav = 0
@@ -1302,5 +1302,5 @@
     grok.context(IDataCenter)
     grok.name('export.csv')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageDataCenter')
 
     def render(self, exporter=None):
@@ -1318,5 +1318,5 @@
     """
     grok.name('export.xml')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.managePortal')
 
     def render(self):
@@ -1335,5 +1335,5 @@
     """
     grok.name('importxml')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.managePortal')
 
     def update(self, xmlfile=None, CANCEL=None, SUBMIT=None):
@@ -1378,5 +1378,5 @@
     grok.context(IFacultiesContainer)
     grok.name('manage')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
     grok.template('facultiescontainermanagepage')
     pnav = 1
@@ -1412,5 +1412,5 @@
     """
     grok.context(IFacultiesContainer)
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
     grok.name('add')
     label = _('Add faculty')
@@ -1453,5 +1453,5 @@
     grok.context(IFaculty)
     grok.name('manage')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
     grok.template('facultymanagepage')
     pnav = 1
@@ -1527,5 +1527,5 @@
     grok.context(IFaculty)
     grok.name('add')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
     label = _('Add department')
     form_fields = grok.AutoFields(IDepartmentAdd)
@@ -1621,5 +1621,5 @@
     grok.context(IDepartment)
     grok.name('manage')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
     pnav = 1
     grok.template('departmentmanagepage')
@@ -1723,5 +1723,5 @@
     grok.context(IDepartment)
     grok.name('addcourse')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
     label = _(u'Add course')
     form_fields = grok.AutoFields(ICourseAdd)
@@ -1760,5 +1760,5 @@
     grok.context(IDepartment)
     grok.name('addcertificate')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
     label = _(u'Add certificate')
     form_fields = grok.AutoFields(ICertificateAdd)
@@ -1814,5 +1814,5 @@
     grok.context(ICourse)
     grok.name('manage')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
     label = _(u'Edit course')
     pnav = 1
@@ -1863,5 +1863,5 @@
     grok.context(ICertificate)
     grok.name('manage')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
     pnav = 1
     label = _('Edit certificate')
@@ -1941,5 +1941,5 @@
     grok.context(ICertificate)
     grok.name('addcertificatecourse')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
     form_fields = grok.AutoFields(ICertificateCourseAdd)
     pnav = 1
@@ -1990,5 +1990,5 @@
     grok.context(ICertificateCourse)
     grok.name('manage')
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
     form_fields = grok.AutoFields(ICertificateCourse)
     label = _('Edit course referrer')
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/viewlets.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/viewlets.py	(revision 8366)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/viewlets.py	(revision 8367)
@@ -155,5 +155,5 @@
     grok.baseclass()
     grok.order(2)
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
     icon = 'actionicon_modify.png'
     target = '@@manage'
@@ -165,5 +165,5 @@
     grok.baseclass()
     grok.order(4)
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
     icon = 'actionicon_add.png'
     target = 'add'
@@ -175,5 +175,5 @@
     grok.baseclass()
     grok.order(4)
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
     icon = 'actionicon_delete.png'
     target = 'remove'
@@ -185,5 +185,5 @@
     grok.baseclass()
     grok.order(5)
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
     icon = 'actionicon_search.png'
     target = 'search'
@@ -236,5 +236,5 @@
 #     #grok.view(Index)
 #     grok.order(98)
-#     grok.require('waeup.manageUniversity')
+#     grok.require('waeup.managePortal')
 
 #class ImportXMLAction(grok.Viewlet):
@@ -242,5 +242,5 @@
 #    #grok.view(Index)
 #    grok.order(99)
-#    grok.require('waeup.manageUniversity')
+#    grok.require('waeup.managePortal')
 #
 #    def update(self):
@@ -259,5 +259,5 @@
     grok.context(IKofaObject)
     grok.order(5)
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
     icon = 'actionicon_modify.png' # File must exist in static/
     title = 'Text of link'
@@ -346,5 +346,5 @@
     every page the user is allowed to go to, if the user has also the
     permissions set by `grok.require()`. By default only users with
     ``waeup.manageUniversity`` permission will see links defined by
     this or derivated classes.
     """
@@ -523,5 +523,5 @@
     grok.template('actionbutton')
     grok.viewletmanager(ActionBar)
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
     icon = 'actionicon_manage.png' # File must exist in static/
     target = '@@show' # link to this viewname.
@@ -542,5 +542,5 @@
     grok.context(IDataCenter)
     grok.view(DatacenterPage)
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.importData')
     grok.order(6)
     icon = 'actionicon_gear.png'
@@ -551,5 +551,5 @@
     grok.context(IDataCenter)
     grok.view(DatacenterPage)
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageDataCenter')
     grok.order(5)
     icon = 'actionicon_up.png'
@@ -560,5 +560,5 @@
     grok.context(IDataCenter)
     grok.view(DatacenterPage)
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageDataCenter')
     grok.order(7)
     icon = 'actionicon_down.png'
@@ -657,5 +657,5 @@
     grok.order(1)
     grok.viewletmanager(AdministrationTasks)
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.managePortal')
     grok.template('admintask')
 
@@ -765,5 +765,5 @@
     grok.viewletmanager(SubobjectLister)
     grok.context(IFaculty)
-    grok.require('waeup.manageUniversity')
+    grok.require('waeup.manageAcademics')
 
     def render(self):
@@ -346,5 +346,5 @@
     every page the user is allowed to go to, if the user has also the
     permissions set by `grok.require()`. By default only users with
-    ``waeup.manageUniversity`` permission will see links defined by
+    ``waeup.manageAcademics`` permission will see links defined by
     this or derivated classes.
     """
